@@ -4,8 +4,8 @@
 ;; Keywords: faces files q
 ;; Package-Requires: ((emacs "24"))
 ;; Created: 8 Jun 2015
-;; Package-Version: 20260101.2301
-;; Package-Revision: 72dea8631501
+;; Package-Version: 20260110.1639
+;; Package-Revision: ce1c5e827c29
 ;; URL: https://github.com/psaris/q-mode
 
 ;; This file is not part of GNU Emacs.
@@ -705,7 +705,7 @@ updates when a buffer is saved."
        (make-process
         :name "q-flymake" :noquery t :connection-type 'pipe
         :buffer (generate-new-buffer " *q-flymake*")
-        :command (list "~/bin/q" (buffer-file-name))
+        :command (list q-program (buffer-file-name))
         :sentinel
         (lambda (proc _event)
           ;; check that the process has exited (not just suspended)
